# MT AWS UTILS

[![PyPI - Version](https://img.shields.io/pypi/v/mt-aws-utils.svg)](https://pypi.org/project/mt-aws-utils)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mt-aws-utils.svg)](https://pypi.org/project/mt-aws-utils)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install mt-aws-utils
```

## License

`mt-aws-utils` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
